# API Docs - v1.0.5

!!! Info "Tested Siddhi Core version: *<a target="_blank" href="http://siddhi.io/en/v5.1/docs/query-guide/">5.1.13</a>*"
    It could also support other Siddhi Core minor versions.

## Sinkmapper

### protobuf *<a target="_blank" href="http://siddhi.io/en/v5.1/docs/query-guide/#sink-mapper">(Sink Mapper)</a>*
<p></p>
<p style="word-wrap: break-word;margin: 0;">This output mapper allows you to convert Events to protobuf messages before publishing them. To work with this mapper you have to add auto-generated protobuf classes to the project classpath. When you use this output mapper, you can either define stream attributes as the same names as the protobuf message attributes or you can use custom mapping to map stream definition attributes with the protobuf attributes. Please find the sample proto definition [here](https://github.com/siddhi-io/siddhi-map-protobuf/tree/master/component/src/main/resources/sample.proto). When you use this mapper with <code>siddhi-io-grpc</code> you don't have to provide the protobuf message class in the <code>class</code> parameter. </p>
<p></p>
<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>

```
@sink(..., @map(type="protobuf", class="<STRING>")
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">class</td>
        <td style="vertical-align: top; word-wrap: break-word"><p style="word-wrap: break-word;margin: 0;">This specifies the class name of the protobuf message class, If sink type is grpc then it's not necessary to provide this parameter.</p></td>
        <td style="vertical-align: top">-</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
@sink(type='inMemory', topic='test01', 
@map(type='protobuf', class='io.siddhi.extension.map.protobuf.autogenerated.Request'))
define stream BarStream (stringValue string, intValue int,longValue long,booleanValue bool,floatValue float,doubleValue double);
```
<p></p>
<p style="word-wrap: break-word;margin: 0;">This will map <code>BarStream</code> values into <code>io.siddhi.extension.map.protobuf.autogenerated.Request</code> protobuf message type.</p>
<p></p>
<span id="example-2" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 2</span>
```
@sink(type='grpc',  publisher.url = 'grpc://localhost:2000/org.wso2.grpc.test.MyService/process 
@map(type='protobuf')) 
define stream BarStream (stringValue string, intValue int,longValue long,booleanValue bool,floatValue float,doubleValue double)
```
<p></p>
<p style="word-wrap: break-word;margin: 0;">Above definition will map <code>BarStream</code> values into the protobuf messages. Since this is a <code>grpc</code> sink, protobuf mapper will get the type of the protobuf class by the <code>publisher.url</code>.</p>
<p></p>
<span id="example-3" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 3</span>
```
@sink(type='grpc', publisher.url = 'grpc://localhost:2000/org.wso2.grpc.test.MyService/process
@map(type='protobuf'), 
@payload(stringValue='a',longValue='b',intValue='c',booleanValue='d',floatValue = 'e', doubleValue  = 'f'))) 
define stream BarStream (a string, b long, c int,d bool,e float,f double);
```
<p></p>
<p style="word-wrap: break-word;margin: 0;">This will map BarStream values to request message type of the <code>process</code> method in <code>MyService</code> service. and stream values will map like this, <br>- value of <code>a</code> will be assign <code>stringValue</code> variable in the message class <br>- value of <code>b</code> will be assign <code>longValue</code> variable in the message class <br>- value of <code>c</code> will be assign <code>intValue</code> variable in the message class <br>- value of <code>d</code> will be assign <code>booleanValue</code> variable in the message class <br>- value of <code>e</code> will be assign <code>floatValue</code> variable in the message class <br>- value of <code>f</code> will be assign <code>doubleValue</code> variable in the message class <br></p>
<p></p>
<span id="example-4" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 4</span>
```
@sink(type='inMemory', topic='test01', 
@map(type='protobuf' class='io.siddhi.extension.map.protobuf.autogenerated.RequestWithList')) 
 define stream BarStream (stringValue string,intValue int,stringList object, intList object);
```
<p></p>
<p style="word-wrap: break-word;margin: 0;">This will map <code>BarStream</code> values into <code>io.siddhi.extension.map.protobuf.autogenerated.RequestWithList</code>. If you want to map data types other than the scalar data types, you have to use <code>object</code> as the data type as shown in above(<code>stringList object</code>).</p>
<p></p>
## Sourcemapper

### protobuf *<a target="_blank" href="http://siddhi.io/en/v5.1/docs/query-guide/#source-mapper">(Source Mapper)</a>*
<p></p>
<p style="word-wrap: break-word;margin: 0;">This input mapper allows you to convert protobuf messages into Events. To work with this input mapper you have to add auto-generated protobuf classes to the project classpath. When you use this input mapper, you can either define stream attributes as the same names as the protobuf message attributes or you can use custom mapping to map stream definition attributes with the protobuf attributes.Please find the sample proto definition [here](https://github.com/siddhi-io/siddhi-map-protobuf/tree/master/component/src/main/resources/sample.proto). When you use this mapper with <code>siddhi-io-grpc</code> you don't have to provide the protobuf message class in the <code>class</code> parameter.  </p>
<p></p>
<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>

```
@source(..., @map(type="protobuf", class="<STRING>")
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">class</td>
        <td style="vertical-align: top; word-wrap: break-word"><p style="word-wrap: break-word;margin: 0;">This specifies the class name of the protobuf message class, If sink type is grpc then it's not necessary to provide this field.</p></td>
        <td style="vertical-align: top">-</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
@source(type='inMemory', topic='test01', 
@map(type='protobuf', class='io.siddhi.extension.map.protobuf.autogenerated.Request')) 
define stream FooStream (stringValue string, intValue int,longValue long,booleanValue bool,floatValue float,doubleValue double); 

```
<p></p>
<p style="word-wrap: break-word;margin: 0;">This will convert the <code>io.siddhi.extension.map.protobuf.autogenerated.Request</code> protobuf messages into siddhi events.</p>
<p></p>
<span id="example-2" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 2</span>
```
source(type='grpc', receiver.url = 'grpc://localhost:8084/org.wso2.grpc.test.MyService/process', 
@map(type='protobuf')) define stream FooStream (stringValue string, intValue int,longValue long,booleanValue bool,floatValue float,doubleValue double); 
```
<p></p>
<p style="word-wrap: break-word;margin: 0;">This will convert the protobuf messages that are received to this source into siddhi events. Since this is <code>grpc</code> source we don't need to provide the <code>class</code> parameter</p>
<p></p>
<span id="example-3" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 3</span>
```
source(type='grpc', receiver.url = 'grpc://localhost:8084/org.wso2.grpc.test.MyService/process', 
@map(type='protobuf', @attributes(a = 'stringValue', b = 'intValue', c = 'longValue',d = 'booleanValue',' e = floatValue', f ='doubleValue'))) 
define stream FooStream (a string ,c long,b int, d bool,e float,f double);
```
<p></p>
<p style="word-wrap: break-word;margin: 0;">This will convert the protobuf messages that are received to this source into siddhi events. since there's a mapping available for the stream, protobuf message object will be map like this, <br>- <code>stringValue</code> of the protobuf message will be assign to the <code>a</code> attribute of the stream <br>- <code>intValue</code> of the protobuf message will be assign to the <code>b</code> attribute of the stream <br>- <code>longValue</code> of the protobuf message will be assign to the <code>c</code> attribute of the stream <br>- <code>booleanValue</code> of the protobuf message will be assign to the <code>d</code> attribute of the stream <br>- <code>floatValue</code> of the protobuf message will be assign to the <code>e</code> attribute of the stream <br>- <code>doubleValue</code> of the protobuf message will be assign to the <code>f</code> attribute of the stream <br></p>
<p></p>
<span id="example-4" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 4</span>
```
source((type='inMemory', topic='test01', 
@map(type='protobuf', class='io.siddhi.extension.map.protobuf.autogenerated.RequestWithList)) 
define stream FooStream (stringValue string ,intValue int,stringList object, intList object););
```
<p></p>
<p style="word-wrap: break-word;margin: 0;">This will convert the <code>io.siddhi.extension.map.protobuf.autogenerated.RequestWithList</code> protobuf messages that are received to this source into siddhi events. If you want to map data types other than the scalar data types, you have to use <code>object</code> as the data type as shown in above(<code>stringList object</code>)</p>
<p></p>
